#
# spec file for package perl-MooseX-App
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MooseX-App
Name:           perl-MooseX-App
Version:        1.430.0
Release:        2.1
%define cpan_version 1.43
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Write user-friendly command line apps with even less suffering
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MAROS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Config::Any)
BuildRequires:  perl(List::Util) >= 1.44
BuildRequires:  perl(Module::Pluggable)
BuildRequires:  perl(Moose) >= 2.00
BuildRequires:  perl(Pod::Elemental)
BuildRequires:  perl(Test::Most)
BuildRequires:  perl(Test::NoWarnings)
BuildRequires:  perl(namespace::autoclean)
Requires:       perl(Config::Any)
Requires:       perl(List::Util) >= 1.44
Requires:       perl(Module::Pluggable)
Requires:       perl(Moose) >= 2.00
Requires:       perl(Pod::Elemental)
Requires:       perl(namespace::autoclean)
Provides:       perl(Moose::Meta::Attribute::Custom::Trait::AppDepends)
Provides:       perl(Moose::Meta::Attribute::Custom::Trait::AppMutexGroup)
Provides:       perl(Moose::Meta::Attribute::Custom::Trait::AppOption)
Provides:       perl(Moose::Meta::Attribute::Custom::Trait::AppTerm)
Provides:       perl(MooseX::App) = 1.430.0
Provides:       perl(MooseX::App::Command)
Provides:       perl(MooseX::App::Exporter)
Provides:       perl(MooseX::App::Message::Block)
Provides:       perl(MooseX::App::Message::BlockColor)
Provides:       perl(MooseX::App::Message::Envelope)
Provides:       perl(MooseX::App::Meta::Role::Attribute::Option)
Provides:       perl(MooseX::App::Meta::Role::Class::Base)
Provides:       perl(MooseX::App::Meta::Role::Class::Command)
Provides:       perl(MooseX::App::Meta::Role::Class::Documentation)
Provides:       perl(MooseX::App::Meta::Role::Class::Simple)
Provides:       perl(MooseX::App::Null)
Provides:       perl(MooseX::App::ParsedArgv)
Provides:       perl(MooseX::App::ParsedArgv::Element)
Provides:       perl(MooseX::App::ParsedArgv::Value)
Provides:       perl(MooseX::App::Plugin::BashCompletion)
Provides:       perl(MooseX::App::Plugin::BashCompletion::Command)
Provides:       perl(MooseX::App::Plugin::BashCompletion::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Color)
Provides:       perl(MooseX::App::Plugin::Color::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Config)
Provides:       perl(MooseX::App::Plugin::Config::Meta::Class)
Provides:       perl(MooseX::App::Plugin::ConfigHome)
Provides:       perl(MooseX::App::Plugin::ConfigHome::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Depends)
Provides:       perl(MooseX::App::Plugin::Depends::Meta::Attribute)
Provides:       perl(MooseX::App::Plugin::Depends::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Env)
Provides:       perl(MooseX::App::Plugin::Fuzzy)
Provides:       perl(MooseX::App::Plugin::Man)
Provides:       perl(MooseX::App::Plugin::Man::Command)
Provides:       perl(MooseX::App::Plugin::Man::Meta::Class)
Provides:       perl(MooseX::App::Plugin::MutexGroup)
Provides:       perl(MooseX::App::Plugin::MutexGroup::Meta::Attribute)
Provides:       perl(MooseX::App::Plugin::MutexGroup::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Term)
Provides:       perl(MooseX::App::Plugin::Term::Meta::Attribute)
Provides:       perl(MooseX::App::Plugin::Term::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Typo)
Provides:       perl(MooseX::App::Plugin::Typo::Meta::Class)
Provides:       perl(MooseX::App::Plugin::Version)
Provides:       perl(MooseX::App::Plugin::Version::Command)
Provides:       perl(MooseX::App::Plugin::Version::Meta::Class)
Provides:       perl(MooseX::App::Role)
Provides:       perl(MooseX::App::Role::Base)
Provides:       perl(MooseX::App::Role::Common)
Provides:       perl(MooseX::App::Simple) = 1.42
Provides:       perl(MooseX::App::Utils)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  perl(Config::Any)
# MANUAL END

%description
MooseX-App is a highly customisable helper to write user-friendly command
line applications without having to worry about most of the annoying things
usually involved. Just take any existing Moose class, add a single line
('use MooseX-App qw(PluginA PluginB ...);') and create one class for each
command in an underlying namespace. Options and positional parameters can
be defined as simple Moose accessors using the 'option' and 'parameter'
keywords respectively.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md TODO
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Oct 26 2023 Tina Müller <tina.mueller@suse.com>
- Remove 70.patch and 71.patch: fixed upstream
* Sun Oct 22 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.43
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.43 2023-10-21
  - Remove duplicate license
  - Require Config::Any
  - Fix cmd_aliases for flags (fixed by William Barker)
  - Remove smartmatch (implemented by Petr Pisar)
  - Allow to override build date with SOURCE_DATE_EPOCH (implemented by Bernhard M. Wiedemann)
* Thu Oct 19 2023 Tina Müller <tina.mueller@suse.com>
- Add 71.patch: Allow to override build date with SOURCE_DATE_EPOCH
* Wed Aug  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 70.patch: Remove given, when, and smartmatch operators; fix
  build with Perl 5.38.
* Tue Aug 17 2021 Frank Schreiner <FSchreiner@suse.com>
- updated to 1.42
  * Documentation
  * Fix failing tests with new Moose versions
  * removed 0001_fix_testing_for_Moose_2.2014.patch
  * Sort option in bash completion plugin
  * removed 0000_reproducible_bash_completion.patch
  * Fixed term plugin warning
* Tue Feb 16 2021 Frank Schreiner <FSchreiner@suse.com>
-  fixes boo#1181616
  addded 0000_reproducible_bash_completion.patch.
  Sort options in bash completion to get reproducible builds.
-  added 0001_fix_testing_for_Moose_2.2014.patch
  fixes https://github.com/maros/MooseX-App/issues/62
* Tue May 14 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.41
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.41 2019-05-13
  - Switch to Dist::Zilla
  1.40 2019-05-13
  - Disable 11_process.t on NetBSD since fork is failing (forking is only done
    during testing and not by the actual module)
  - Sort keys operations to get a predictable order of keys (implemented by Jose Luis Martinez)
  - Simplify dependencies: No need for Path::Class. File::Spec and File::Basename that are
    loaded via Module::Pluggable::Object are sufficient
  1.39 2017-09-24
  - APP_DEVELOPER environment for extended module checks
  - Improved command checks: Die on single letter flags without Bool type constraints
* Mon Sep 25 2017 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-MooseX-App/Changes
* Thu May 25 2017 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.38 2017-06-20
  - Cleanups (get rid of smartmatch, inentation, documentation, tests)
  - Also handle =head[2-4] tags when processing pod (#47)
  - Subcommands (based on work by Yanick Champoux)
* Wed Feb 22 2017 coolo@suse.com
- updated to 1.3701
  see /usr/share/doc/packages/perl-MooseX-App/Changes
* Mon Nov 14 2016 coolo@suse.com
- updated to 1.37
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.37 2016-11-13
  - Refactor the way values are parsed from @ARGV
  - Rework boolean negation
  - Add developer checks
* Wed Oct 12 2016 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.36 2016-10-11
  - Documentation
  - Set correct encoding on STDERR
  - Fix order of options (fixed by J.R. Mash)
  - Replace dashes in variable names with underscores in bash completion (implemented by Tina Müller)
  - Do not autocomplete autocomplete itself (implemented by Lisa Hare)
  - Create correct documentation for options with cmd_split
  - Rename hints key to clarify purpose
  - Add ability to negate boolean options (implemented by Marc Logghe)
  - Spelling fixes github#39 (fixed by Gregor Herrmann)
  - Retain original order of elements from @ARGV
* Mon Apr  4 2016 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.35 2016-04-02
  - Apply Spelling fixes RT112234 (fixed by Gregor Herrmann)
  - Documentation
  - Allow to pass ARGV directly to constructor
  - use namespace::autoclean (reported by Mohammad S Anwar)
  - Dist housekeeping
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.34
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.34 2016-02-21
  - Do not accept invalid character in Term plugin
  - Fix RT112156: Command class lacking attribute metarole (reported by Marc Logghe)
  - Apply Spelling fixes RT105717 (fixed by Gregor Herrmann)
  - Add permute option to specify multiple values with one attribute key
  - Fix imports (fixed by Alexander Stoddard)
  - Documentation
* Sun Apr 19 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
